@@ -9,7 +9,7 @@
 #
 package Pod::Weaver::PluginBundle::RSRCHBOY;
 {
-  $Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.013';
+  $Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.014';
 }
 
 # ABSTRACT: Document your modules like RSRCHBOY does
@@ -17,14 +17,15 @@ package Pod::Weaver::PluginBundle::RSRCHBOY;
 use strict;
 use warnings;
 
+# for prereqs
+use Pod::Weaver::Section::SeeAlso      ( );
+use Pod::Weaver::Section::SourceGitHub ( );
+
 use Pod::Weaver::Config::Assembler;
 
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 sub _exp2 { [ "\@RSRCHBOY/$_[0]", _exp($_[0]), {} ] }
 
-use Pod::Weaver::Config::Assembler;
-
-
 sub mvp_bundle_config {
     return (
         [ '@RSRCHBOY/CorePrep',  _exp('@CorePrep'),    {} ],
@@ -70,7 +71,7 @@ Pod::Weaver::PluginBundle::RSRCHBOY - Document your modules like RSRCHBOY does
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
